Enum Hu
#[repr(u8)]pub enum Hu {
Perfect = 0,
Hash = 1,
}Variants
Perfect = 0
MAC performs a perfect destination address filtering for unicast frames
Hash = 1
MAC performs destination address filtering of received unicast frames according to the hash table
Implementations